@@ -6,7 +6,7 @@ void	dvap_skip(void);
 void	dvap_send_wait_set(void);
 
 struct	termios	save_attr;
-char	dvap_buff[320];
+char	dvap_buff[1024];
 char	dvap_header[47];
 char	dvap_voice[18];
 extern	char	lastframe[];
@@ -71,6 +71,11 @@ void    dvap_last_frame_send (void)
 		dvap_send_wait_set();
 	}
 
+	if (RespRp->next)
+	{
+		gettimeofday (&resp_timer, NULL);
+	}
+
         if (monitor_port)
         {
                 if (sendto (monitor_sd, &dvap_pkt, 32, 0,
@@ -480,11 +485,13 @@ void	dvap(void)
                         dvap_check_wait = FALSE;
                         dvap_state = DVAP_CALIBRATION_CLEAR_CHECK;
                         break;
+
                 case DVAP_CALIBRATION_CLEAR_CHECK:
                         ret = write (dvap_fd, error_check, 4);
                         dvap_loop_cnt = 0;
                         dvap_state = DVAP_CALIBRATION_CLEAR_WAIT;
                         break;
+
                 case DVAP_CALIBRATION_CLEAR_WAIT:
                         if (!dvap_check_wait)
                         {
@@ -566,6 +573,8 @@ void	dvap_open(void)
 {
         struct termios attr;
 
+	if (dvap_fd) return;
+
         dvap_fd = open(DVAP_DEVICE, O_RDWR | O_NOCTTY | O_NONBLOCK);
         if (dvap_fd < 0) 
 	{
@@ -620,7 +629,6 @@ void	dvap_close (void)
 	RunState[4] = 0x00;
 	write (dvap_fd, RunState, 5);
 	tcsetattr (dvap_fd, TCSANOW, &save_attr);
-	close (dvap_fd);
 	dvap_NoRespReply_sw = FALSE;
 	dvap_skip();
 	dvap_gw_resp_sw = FALSE;
@@ -634,6 +642,8 @@ void	dvap_close (void)
 	}
 	dvap_sw = FALSE;
 	FD_CLR (dvap_fd, &save_rfds);
+	close (dvap_fd);
+	dvap_fd = 0;
 }
 
 void	dvap_send_header (void)
@@ -707,7 +717,7 @@ void	dvap_send_voice (void)
 {
 	int	length;
 
-	if (!dvap_voice_send_sw) return;
+	//if (!dvap_voice_send_sw) return;
 	dvap_rig_pkt_cnt++;
 	memcpy (&dvap_pkt.dstar.b_bone.dstar_udp.voice_d, &dvap_voice[6], 12);
 	dv_pkt_set(&dvap_pkt);
@@ -718,7 +728,7 @@ void	dvap_send_voice (void)
 	{
 		memcpy (&dvap_pkt.dstar.b_bone.dstar_udp.voice_d.data_segment, lastframe, 6);
 		dvap_pkt.length[1] = 22;  /* 32 - 10 */
-		putFifo (32, dvap_pkt);
+		if (dvap_voice_send_sw) putFifo (32, dvap_pkt);
 		length = 32;
 		dvap_last_frame_sw = FALSE;
                 if (debug)
@@ -731,11 +741,12 @@ void	dvap_send_voice (void)
 		{
 			dvap_send_wait_set();
 		}
+		if (RespRp->next) gettimeofday(&resp_timer, NULL);
 	}
 	else
 	{
 		dvap_pkt.length[1] = 19;  /* 29 - 10 */
-		putFifo (29, dvap_pkt);
+		if (dvap_voice_send_sw) putFifo (29, dvap_pkt);
 		length = 29;
 	}
 
@@ -761,9 +772,10 @@ void	dvap_read(void)
 	struct	timeval	in_time;
 	struct	timeval	tmp_time;
 	struct	timeval	interval_time;
+	ssize_t	wrt_len;
 
 	interval_time.tv_sec = 0;
-	interval_time.tv_usec = 10000;
+	interval_time.tv_usec = 500000;
 	gettimeofday (&in_time, NULL);
 	timersub (&in_time, &dvap_in_time, &tmp_time);
 	if (timercmp (&tmp_time, &interval_time, >)) dvap_buff_pnt = 0;
@@ -782,24 +794,19 @@ void	dvap_read(void)
 	}
 
 	dvap_buff_pnt += len;
+
+	while (dvap_buff_pnt)
+	{
 	n = dvap_buff[0] | ((dvap_buff[1] & 0x1f) << 8);
 	if (n > dvap_buff_pnt) return;
 
-/*
-	for (k = 0 ; k < n ; k++)
-	{
-		printf ("%2.2x ", dvap_buff[k]);
-	}
-	printf ("\n");
-*/
-
 	/* header */
 	if (n == 47)
 	{
 		if ((dvap_buff[1] & 0xe0) == 0xa0)	/* header */
 		{
 			dvap_ack[2] = 0x01;
-			write (dvap_fd, dvap_ack, 3);
+			wrt_len = write (dvap_fd, dvap_ack, 3);
 			gettimeofday (&dvap_InTime, NULL);
 			memcpy (dvap_header, dvap_buff, dvap_buff_pnt);
 			dvap_send_header();
@@ -813,7 +820,7 @@ void	dvap_read(void)
 	if ((n == 18) && ((dvap_buff[1] & 0xe0) == 0xc0))
 	{
 		dvap_ack[2] = 0x02;
-		write (dvap_fd, dvap_ack, 3);
+		wrt_len = write (dvap_fd, dvap_ack, 3);
 
 		gettimeofday (&dvap_InTime, NULL);
 		memcpy (dvap_voice, dvap_buff, dvap_buff_pnt);
@@ -823,15 +830,6 @@ void	dvap_read(void)
 	{
 		band_scan_sw = TRUE;
 		memcpy (rssi, &dvap_buff[4], 201);
-/*
-		freq = dvap_freq - 10000;
-		for (k = 4 ; k < n  ; k++)
-		{
-			fprintf (log_file, "%ld %d\n", freq, dvap_buff[k]);
-			freq += 100;
-		}
-		fflush (log_file);
-*/
 	}
 	/* status / error code */
 	if (n >= 5)
@@ -879,9 +877,6 @@ void	dvap_read(void)
 	k = dvap_buff_pnt - n;
 	if (k > 0) memmove (&dvap_buff[0], &dvap_buff[n], k);
 	dvap_buff_pnt = k;
-	if (dvap_buff_pnt > 160)
-	{
-		dvap_buff_pnt = 0;
 	}
 }
 	
