@@ -2,29 +2,17 @@
 
 void	node_usb_init(void)
 {
-	if (node_area_rep_callsign[0] == 0x20)
+	if (node_area_rep_callsign[0] == 0x20) 
 	{
 		node_sw = FALSE;
 		return;
 	}
-
 	udev = NULL;
 	dev_found = FALSE;
 	usb_init();
 	usb_find_busses();
 	usb_find_devices();
 
-	if (debug)
-	{
-		if (node_sw)
-		{
-			time (&cur_time);
-			fprintf (log_file, "%24.24s Node Adapter VenderID:0x%4.4x ProductID:0x%4.4x\n",
-				ctime(&cur_time), VenderID, ProductID);
-			fflush (log_file);
-		}
-	}
-
         for (bus = usb_get_busses(); bus && !dev_found; bus = bus->next) {
                 for (dev = bus->devices; dev && !dev_found; dev = dev->next) {
                   if ((dev->descriptor.idVendor == VenderID) 
@@ -41,7 +29,7 @@ void	node_usb_init(void)
 		if (node_sw)
 		{
 			time (&cur_time);
-                	fprintf(log_file, 
+               		fprintf(log_file, 
 				"\n%24.24s Please check the USB Cable! or Node Adapter!\n", 
 				ctime(&cur_time));
 			fflush (log_file);
@@ -58,6 +46,13 @@ void	node_usb_init(void)
 		node_close();
 		return;
 	}
+        if (debug)
+        {
+                time (&cur_time);
+                fprintf (log_file, "%24.24s Node Adapter VenderID:0x%4.4x ProductID:0x%4.4x\n",
+                        ctime(&cur_time), VenderID, ProductID);
+                fflush (log_file);
+        }
 
 	if (debug) print_PICinfo();
 
